@@ -13,19 +13,16 @@
     For more details, please visit: http://mac.citi.sinica.edu.tw/ikala/
 
 """
-
 import csv
 import os
-import librosa
-import logging
-import numpy as np
 from typing import BinaryIO, Optional, TextIO, Tuple
 
-from mirdata import download_utils
-from mirdata import jams_utils
-from mirdata import core
-from mirdata import annotations
-from mirdata import io
+from deprecated.sphinx import deprecated
+import librosa
+import numpy as np
+from smart_open import open
+
+from mirdata import annotations, core, download_utils, jams_utils, io
 
 
 BIBTEX = """@inproceedings{chan2015vocal,
@@ -37,16 +34,30 @@ BIBTEX = """@inproceedings{chan2015vocal,
     year={2015},
     organization={IEEE}
 }"""
+
+INDEXES = {
+    "default": "2.0",
+    "test": "2.0",
+    "1.0": core.Index(filename="ikala_index_1.0.json", partial_download=["metadata"]),
+    "2.0": core.Index(filename="ikala_index_2.0.json"),
+}
+
 TIME_STEP = 0.032  # seconds
 REMOTES = {
     "metadata": download_utils.RemoteFileMetadata(
         filename="id_mapping.txt",
         url="http://mac.citi.sinica.edu.tw/ikala/id_mapping.txt",
         checksum="81097b587804ce93e56c7a331ba06abc",
-    )
+    ),
+    "notes_pyin": download_utils.RemoteFileMetadata(
+        filename="ikala-pyin-notes.zip",
+        url="https://zenodo.org/record/4728756/files/ikala-pyin-notes.zip?download=1",
+        checksum="8b9464a48b11bf26762de9c18a3a51ea",
+    ),
 }
+
 DOWNLOAD_INFO = """
-    Unfortunately the iKala dataset is not available for download.
+    Unfortunately most of the iKala dataset is not available for download.
     If you have the iKala dataset, place the contents into a folder called
     iKala with the following structure:
         > iKala/
@@ -71,6 +82,7 @@ class Track(core.Track):
     Attributes:
         audio_path (str): path to the track's audio file
         f0_path (str): path to the track's f0 annotation file
+        notes_pyin_path (str): path to the note annotation file
         lyrics_path (str): path to the track's lyric annotation file
         section (str): section. Either 'verse' or 'chorus'
         singer_id (str): singer id
@@ -79,7 +91,9 @@ class Track(core.Track):
 
     Cached Properties:
         f0 (F0Data): human-annotated singing voice pitch
+        notes_pyin (NoteData): notes estimated by the pyin algorithm
         lyrics (LyricsData): human-annotated lyrics
+        pronunciations (LyricsData): human-annotation lyric pronunciations
 
     """
 
@@ -101,6 +115,7 @@ class Track(core.Track):
 
         self.f0_path = self.get_path("pitch")
         self.lyrics_path = self.get_path("lyrics")
+        self.notes_pyin_path = self.get_path("notes_pyin")
 
         self.audio_path = self.get_path("audio")
 
@@ -115,10 +130,18 @@ class Track(core.Track):
     def f0(self) -> Optional[annotations.F0Data]:
         return load_f0(self.f0_path)
 
+    @core.cached_property
+    def notes_pyin(self) -> Optional[annotations.NoteData]:
+        return load_notes(self.notes_pyin_path)
+
     @core.cached_property
     def lyrics(self) -> Optional[annotations.LyricData]:
         return load_lyrics(self.lyrics_path)
 
+    @core.cached_property
+    def pronunciations(self) -> Optional[annotations.LyricData]:
+        return load_pronunciations(self.lyrics_path)
+
     @property
     def vocal_audio(self) -> Optional[Tuple[np.ndarray, float]]:
         """solo vocal audio (mono)
@@ -162,6 +185,7 @@ class Track(core.Track):
         return jams_utils.jams_converter(
             audio_path=self.audio_path,
             f0_data=[(self.f0, None)],
+            note_data=[(self.notes_pyin, "pyin estimated notes")],
             lyrics_data=[(self.lyrics, None)],
             metadata={
                 "section": self.section,
@@ -240,12 +264,38 @@ def load_f0(fhandle: TextIO) -> annotations.F0Data:
     lines = fhandle.readlines()
     f0_midi = np.array([float(line) for line in lines])
     f0_hz = librosa.midi_to_hz(f0_midi) * (f0_midi > 0)
-    confidence = (f0_hz > 0).astype(float)
+    voicing = (f0_hz > 0).astype(float)
+    f0_hz = np.abs(f0_hz)
     times = (np.arange(len(f0_midi)) * TIME_STEP) + (TIME_STEP / 2.0)
-    f0_data = annotations.F0Data(times, f0_hz, confidence)
+    f0_data = annotations.F0Data(times, "s", f0_hz, "hz", voicing, "binary")
     return f0_data
 
 
+@io.coerce_to_string_io
+def load_notes(fhandle: TextIO) -> Optional[annotations.NoteData]:
+    """load a note annotation file
+
+    Args:
+        fhandle (str or file-like): str or file-like to note annotation file
+
+    Raises:
+        IOError: if file doesn't exist
+
+    Returns:
+        NoteData: note annotation
+
+    """
+    intervals = []
+    freqs = []
+    reader = csv.reader(fhandle, delimiter=",")
+    for line in reader:
+        start_time = float(line[0])
+        intervals.append([start_time, start_time + float(line[1])])
+        freqs.append(float(line[2]))
+
+    return annotations.NoteData(np.array(intervals), "s", np.array(freqs), "hz")
+
+
 @io.coerce_to_string_io
 def load_lyrics(fhandle: TextIO) -> annotations.LyricData:
     """Load an ikala lyrics annotation
@@ -276,10 +326,45 @@ def load_lyrics(fhandle: TextIO) -> annotations.LyricData:
         else:
             pronunciations.append("")
 
+    lyrics_data = annotations.LyricData(
+        np.array([start_times, end_times]).T, "s", lyrics, "words"
+    )
+    return lyrics_data
+
+
+@io.coerce_to_string_io
+def load_pronunciations(fhandle: TextIO) -> annotations.LyricData:
+    """Load an ikala pronunciation annotation
+
+    Args:
+        fhandle (str or file-like): File-like object or path to lyric annotation file
+
+    Raises:
+        IOError: if lyrics_path does not exist
+
+    Returns:
+        LyricData: pronunciation annotation data
+
+    """
+    # input: start time (ms), end time (ms), lyric, [pronunciation]
+    reader = csv.reader(fhandle, delimiter=" ")
+    start_times = []
+    end_times = []
+    pronunciations = []
+    for line in reader:
+        start_times.append(float(line[0]) / 1000.0)
+        end_times.append(float(line[1]) / 1000.0)
+        if len(line) > 2:
+            pronunciation = " ".join(line[3:])
+            pronunciations.append(pronunciation)
+        else:
+            pronunciations.append("")
+
     lyrics_data = annotations.LyricData(
         np.array([start_times, end_times]).T,
-        lyrics,
+        "s",
         pronunciations,
+        "pronunciations_open",
     )
     return lyrics_data
 
@@ -290,12 +375,14 @@ class Dataset(core.Dataset):
     The ikala dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="ikala",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             download_info=DOWNLOAD_INFO,
             license_info=LICENSE_INFO,
@@ -304,35 +391,64 @@ class Dataset(core.Dataset):
     @core.cached_property
     def _metadata(self):
         id_map_path = os.path.join(self.data_home, "id_mapping.txt")
-        if not os.path.exists(id_map_path):
+        try:
+            with open(id_map_path, "r") as fhandle:
+                reader = csv.reader(fhandle, delimiter="\t")
+                singer_map = {}
+                for line in reader:
+                    if line[0] == "singer":
+                        continue
+                    singer_map[line[1]] = line[0]
+        except FileNotFoundError:
             raise FileNotFoundError("Metadata not found. Did you run .download()?")
 
-        with open(id_map_path, "r") as fhandle:
-            reader = csv.reader(fhandle, delimiter="\t")
-            singer_map = {}
-            for line in reader:
-                if line[0] == "singer":
-                    continue
-                singer_map[line[1]] = line[0]
-
         return singer_map
 
-    @core.copy_docs(load_vocal_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_vocal_audio",
+        version="0.3.4",
+    )
     def load_vocal_audio(self, *args, **kwargs):
         return load_vocal_audio(*args, **kwargs)
 
-    @core.copy_docs(load_instrumental_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_instrumental_audio",
+        version="0.3.4",
+    )
     def load_instrumental_audio(self, *args, **kwargs):
         return load_instrumental_audio(*args, **kwargs)
 
-    @core.copy_docs(load_mix_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_mix_audio",
+        version="0.3.4",
+    )
     def load_mix_audio(self, *args, **kwargs):
         return load_mix_audio(*args, **kwargs)
 
-    @core.copy_docs(load_f0)
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_f0",
+        version="0.3.4",
+    )
     def load_f0(self, *args, **kwargs):
         return load_f0(*args, **kwargs)
 
-    @core.copy_docs(load_lyrics)
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_notes",
+        version="0.3.4",
+    )
+    def load_notes(self, *args, **kwargs):
+        return load_notes(*args, **kwargs)
+
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_lyrics",
+        version="0.3.4",
+    )
     def load_lyrics(self, *args, **kwargs):
         return load_lyrics(*args, **kwargs)
+
+    @deprecated(
+        reason="Use mirdata.datasets.ikala.load_pronunciations",
+        version="0.3.4",
+    )
+    def load_pronunciations(self, *args, **kwargs):
+        return load_pronunciations(*args, **kwargs)
