@@ -89,17 +89,14 @@ IRMAS Loader
 
 """
 import csv
-
 import os
 from typing import BinaryIO, List, Optional, TextIO, Tuple
 
+from deprecated.sphinx import deprecated
 import librosa
 import numpy as np
 
-from mirdata import download_utils
-from mirdata import jams_utils
-from mirdata import core
-from mirdata import io
+from mirdata import core, download_utils, io, jams_utils
 
 BIBTEX = """
 @dataset{juan_j_bosch_2014_1290750,
@@ -113,6 +110,12 @@ BIBTEX = """
   url          = {https://doi.org/10.5281/zenodo.1290750}
 """
 
+INDEXES = {
+    "default": "1.0",
+    "test": "1.0",
+    "1.0": core.Index(filename="irmas_index_1.0.json"),
+}
+
 REMOTES = {
     "training_data": download_utils.RemoteFileMetadata(
         filename="IRMAS-TrainingData.zip",
@@ -320,20 +323,28 @@ class Dataset(core.Dataset):
     The irmas dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="irmas",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             license_info=LICENSE_INFO,
         )
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.irmas.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_pred_inst)
+    @deprecated(
+        reason="Use mirdata.datasets.irmas.load_pred_inst",
+        version="0.3.4",
+    )
     def load_pred_inst(self, *args, **kwargs):
         return load_pred_inst(*args, **kwargs)
