@@ -44,18 +44,13 @@
     For more details, please visit: https://www.upf.edu/web/mtg/phenicx-anechoic
 
 """
-import logging
-import os, glob, re
-import jams
-import librosa
-import numpy as np
 from typing import BinaryIO, Optional, TextIO, Tuple, cast
 
-from mirdata import download_utils
-from mirdata import jams_utils
-from mirdata import core
-from mirdata import annotations
-from mirdata import io
+from deprecated.sphinx import deprecated
+import librosa
+import numpy as np
+
+from mirdata import annotations, core, download_utils, io, jams_utils
 
 
 BIBTEX = """
@@ -79,6 +74,12 @@ BIBTEX = """
 }
 """
 
+INDEXES = {
+    "default": "1",
+    "test": "1",
+    "1": core.Index(filename="phenicx_anechoic_index_1.json"),
+}
+
 REMOTES = {
     "all": download_utils.RemoteFileMetadata(
         filename="PHENICX-Anechoic.zip",
@@ -122,7 +123,8 @@ class Track(core.Track):
         track_id (str): track id
 
     Cached Properties:
-        melody (F0Data): melody annotation
+        notes (NoteData): notes annotations that have been time-aligned to the audio
+        notes_original (NoteData): original score representation, not time-aligned
 
     """
 
@@ -322,23 +324,14 @@ class MultiTrack(core.MultiTrack):
             NoteData: Note data for the tracks
 
         """
-        values = []
-        intervals = []
+        notes_target = None
         for k in track_keys:
             score = getattr(self.tracks[k], notes_property)
-            values.append(score.notes)
-            intervals.append(score.intervals)
-        values = np.hstack(values)
-        intervals = np.vstack(intervals)
-
-        #### sort on the start time
-        ind = np.argsort(intervals[:, 0], axis=0)
-        start_times = np.take_along_axis(intervals[:, 0], ind, axis=0)
-        end_times = np.take_along_axis(intervals[:, 1], ind, axis=0)
-        intervals = np.vstack([start_times, end_times]).T
-        values = np.take_along_axis(values, ind, axis=0)
-
-        return annotations.NoteData(intervals, values)
+            if notes_target is None:
+                notes_target = score
+            else:
+                notes_target += score
+        return notes_target
 
     def get_notes_for_instrument(self, instrument, notes_property="notes"):
         """Get the notes for a particular instrument
@@ -405,7 +398,7 @@ def load_score(fhandle: TextIO) -> annotations.NoteData:
         [librosa.note_to_hz(line.split(",")[2].strip("\n")) for line in content]
     )
 
-    return annotations.NoteData(intervals, values)
+    return annotations.NoteData(intervals, "s", values, "hz")
 
 
 @core.docstring_inherit(core.Dataset)
@@ -414,21 +407,29 @@ class Dataset(core.Dataset):
     The Phenicx-Anechoic dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="phenicx_anechoic",
             track_class=Track,
             multitrack_class=MultiTrack,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             license_info=LICENSE_INFO,
         )
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.phenicx_anechoic.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_score)
+    @deprecated(
+        reason="Use mirdata.datasets.phenicx_anechoic.load_score",
+        version="0.3.4",
+    )
     def load_score(self, *args, **kwargs):
         return load_score(*args, **kwargs)
