@@ -7,6 +7,12 @@ def pytest_addoption(parser):
         "--local", action="store_true", default=False, help="run local tests"
     )
     parser.addoption("--dataset", type=str, default="", help="dataset to test locally")
+    parser.addoption(
+        "--dataset-version",
+        type=str,
+        default="default",
+        help="version of dataset to test locally",
+    )
     parser.addoption(
         "--skip-download", action="store_true", default=False, help="skip download step"
     )
@@ -15,11 +21,6 @@ def pytest_addoption(parser):
     )
 
 
-# @pytest.fixture(scope='session')
-# def local(request):
-#     return request.config.getoption('--local')
-
-
 @pytest.fixture(scope="session")
 def skip_local(request):
     if request.config.getoption("--local"):
@@ -37,6 +38,11 @@ def test_dataset(request):
     return request.config.getoption("--dataset")
 
 
+@pytest.fixture(scope="session")
+def dataset_version(request):
+    return request.config.getoption("--dataset-version")
+
+
 @pytest.fixture(scope="session")
 def skip_download(request):
     return request.config.getoption("--skip-download")
