@@ -1,8 +1,10 @@
 import pytest
+import os
 import numpy as np
 
 import mirdata
 from mirdata import core
+from tests.test_utils import DEFAULT_DATA_HOME
 
 
 def test_track():
@@ -151,6 +153,9 @@ def test_multitrack_repr():
 
 
 def test_dataset():
+    dataset = mirdata.initialize("acousticbrainz_genre")
+    assert isinstance(dataset, core.Dataset)
+
     dataset = mirdata.initialize("guitarset")
     assert isinstance(dataset, core.Dataset)
 
@@ -166,6 +171,72 @@ def test_dataset():
     print(dataset)  # test that repr doesn't fail
 
 
+def test_dataset_versions():
+    class VersionTest(core.Dataset):
+        def __init__(self, data_home=None, version="default"):
+            super().__init__(
+                data_home,
+                version,
+                indexes={
+                    "default": "1",
+                    "test": "0",
+                    "0": core.Index("blah_0.json"),
+                    "1": core.Index(
+                        "blah_1.json", url="https://google.com", checksum="asdf"
+                    ),
+                    "2": core.Index("blah_2.json"),
+                    "real": core.Index("beatles_index_1.2.json"),
+                },
+            )
+
+    dataset = VersionTest("asdf")
+    assert dataset.version == "1"
+    assert dataset.index_path == "asdf/mirdata_indexes/blah_1.json"
+
+    dataset_default = VersionTest("asdf", version="default")
+    assert dataset_default.version == "1"
+    assert dataset_default.index_path == "asdf/mirdata_indexes/blah_1.json"
+
+    dataset_1 = VersionTest("asdf", version="1")
+    assert dataset_1.version == "1"
+    assert dataset_1.index_path == "asdf/mirdata_indexes/blah_1.json"
+    with pytest.raises(FileNotFoundError):
+        dataset_1._index
+
+    local_index_path = os.path.dirname(os.path.realpath(__file__))[:-5]
+    dataset_test = VersionTest("asdf", version="test")
+    assert dataset_test.version == "0"
+    assert dataset_test.index_path == os.path.join(
+        local_index_path, "mirdata/datasets/indexes/blah_0.json"
+    )
+
+    with pytest.raises(IOError):
+        dataset_test._index
+
+    dataset_0 = VersionTest("asdf", version="0")
+    assert dataset_0.version == "0"
+    assert dataset_0.index_path == os.path.join(
+        local_index_path, "mirdata/datasets/indexes/blah_0.json"
+    )
+
+    dataset_2 = VersionTest("asdf", version="2")
+    assert dataset_2.version == "2"
+    assert dataset_2.index_path == os.path.join(
+        local_index_path, "mirdata/datasets/indexes/blah_2.json"
+    )
+
+    dataset_real = VersionTest("asdf", version="real")
+    assert dataset_real.version == "real"
+    assert dataset_real.index_path == os.path.join(
+        local_index_path, "mirdata/datasets/indexes/beatles_index_1.2.json"
+    )
+    idx_test = dataset_real._index
+    assert isinstance(idx_test, dict)
+
+    with pytest.raises(ValueError):
+        VersionTest("asdf", version="not_a_version")
+
+
 def test_dataset_errors():
     with pytest.raises(ValueError):
         mirdata.initialize("not_a_dataset")
@@ -296,21 +367,10 @@ def test_multitrack():
 
     class TestMultiTrack1(core.MultiTrack):
         def __init__(
-            self,
-            mtrack_id,
-            data_home,
-            dataset_name,
-            index,
-            track_class,
-            metadata,
+            self, mtrack_id, data_home, dataset_name, index, track_class, metadata
         ):
             super().__init__(
-                mtrack_id,
-                data_home,
-                dataset_name,
-                index,
-                track_class,
-                metadata,
+                mtrack_id, data_home, dataset_name, index, track_class, metadata
             )
 
         def to_jams(self):
@@ -342,21 +402,10 @@ def test_multitrack_mixing():
 
     class TestMultiTrack1(core.MultiTrack):
         def __init__(
-            self,
-            mtrack_id,
-            data_home,
-            dataset_name,
-            index,
-            track_class,
-            metadata,
+            self, mtrack_id, data_home, dataset_name, index, track_class, metadata
         ):
             super().__init__(
-                mtrack_id,
-                data_home,
-                dataset_name,
-                index,
-                track_class,
-                metadata,
+                mtrack_id, data_home, dataset_name, index, track_class, metadata
             )
 
         def to_jams(self):
@@ -445,21 +494,10 @@ def test_multitrack_unequal_len():
 
     class TestMultiTrack1(core.MultiTrack):
         def __init__(
-            self,
-            mtrack_id,
-            data_home,
-            dataset_name,
-            index,
-            track_class,
-            metadata,
+            self, mtrack_id, data_home, dataset_name, index, track_class, metadata
         ):
             super().__init__(
-                mtrack_id,
-                data_home,
-                dataset_name,
-                index,
-                track_class,
-                metadata,
+                mtrack_id, data_home, dataset_name, index, track_class, metadata
             )
 
         def to_jams(self):
@@ -505,21 +543,10 @@ def test_multitrack_unequal_sr():
 
     class TestMultiTrack1(core.MultiTrack):
         def __init__(
-            self,
-            mtrack_id,
-            data_home,
-            dataset_name,
-            index,
-            track_class,
-            metadata,
+            self, mtrack_id, data_home, dataset_name, index, track_class, metadata
         ):
             super().__init__(
-                mtrack_id,
-                data_home,
-                dataset_name,
-                index,
-                track_class,
-                metadata,
+                mtrack_id, data_home, dataset_name, index, track_class, metadata
             )
 
         def to_jams(self):
@@ -560,21 +587,10 @@ def test_multitrack_mono():
 
     class TestMultiTrack1(core.MultiTrack):
         def __init__(
-            self,
-            mtrack_id,
-            data_home,
-            dataset_name,
-            index,
-            track_class,
-            metadata,
+            self, mtrack_id, data_home, dataset_name, index, track_class, metadata
         ):
             super().__init__(
-                mtrack_id,
-                data_home,
-                dataset_name,
-                index,
-                track_class,
-                metadata,
+                mtrack_id, data_home, dataset_name, index, track_class, metadata
             )
 
         def to_jams(self):
@@ -613,21 +629,10 @@ def test_multitrack_mono():
 
     class TestMultiTrack1(core.MultiTrack):
         def __init__(
-            self,
-            mtrack_id,
-            data_home,
-            dataset_name,
-            index,
-            track_class,
-            metadata,
+            self, mtrack_id, data_home, dataset_name, index, track_class, metadata
         ):
             super().__init__(
-                mtrack_id,
-                data_home,
-                dataset_name,
-                index,
-                track_class,
-                metadata,
+                mtrack_id, data_home, dataset_name, index, track_class, metadata
             )
 
         def to_jams(self):
@@ -652,3 +657,67 @@ def test_multitrack_mono():
     target1 = mtrack.get_target(["a", "c"], average=False)
     assert target1.shape == (1, 100)
     assert np.max(np.abs(target1)) <= 2
+
+
+def test_dataset_splits():
+    empty_dataset = core.Dataset(
+        name="test", indexes={"default": core.Index("asdf.json")}
+    )
+
+    # test the case where there are no tracks
+    with pytest.raises(AttributeError):
+        empty_dataset.get_track_splits([0.9, 0.1])
+
+    # test the case where there are no multitracks
+    with pytest.raises(AttributeError):
+        empty_dataset.get_mtrack_splits([0.9, 0.1])
+
+    # test the partition function
+    items = [i for i in range(100)]
+    list_sum_up_1 = [
+        [0.7, 0.1, 0.1, 0.1],
+        [0.4, 0.2, 0.2, 0.2],
+        [0.5, 0.2, 0.2, 0.1],
+        [0.8, 0.1, 0.1],
+        [0.7, 0.2, 0.1],
+        [0.9, 0.1, 0.0],
+        [0.6, 0.3, 0.1],
+        [0.5, 0.4, 0.1],
+        [0.9, 0.05, 0.05],
+        [0.8, 0.2],
+        [0.1, 0.9],
+    ]
+    for right_combination in list_sum_up_1:
+        splits = empty_dataset._get_partitions(items, right_combination, 42)
+        # check that the right number of splits are created
+        assert len(splits) == len(right_combination)
+        # check that the number of total items matches
+        assert len(items) == sum([len(i) for i in splits])
+        # check that all items are used
+        assert set(items) == set([i for split_items in splits for i in split_items])
+        # check that splits are nonoverlapping
+        used = set()
+        for split in splits:
+            this_split = set(split)
+            assert not this_split.intersection(used)
+            used.update(this_split)
+        # check that the split is reproducable
+        splits2 = empty_dataset._get_partitions(items, right_combination, 42)
+        for split, split2 in zip(splits, splits2):
+            assert np.array_equal(split, split2)
+
+    list_not_sum_up_1 = [
+        [0.8, 0.1, 0.3, 0.2],
+        [0.3, 0.1, 0.3, 0.5],
+        [0.8, 0.1, 0.3],
+        [0.3, 0.1, 0.3],
+        [0.9, 0.2, 0.3],
+        [0.1, 0.1, 0.1],
+        [0.95, 0.01, 0.01],
+        [0.8, 0.1, 0.3],
+        [0.8, 0.3],
+        [0.1, 0.7],
+    ]
+    for wrong_combination in list_not_sum_up_1:
+        with pytest.raises(ValueError):
+            empty_dataset._get_partitions(items, wrong_combination, 42)
